pub trait Data {
// Required methods
fn does_stream_format_match(stream_format: &StreamFormat) -> bool;
unsafe fn from_input_proc_args(
num_frames: u32,
io_data: *mut AudioBufferList,
) -> Self;
}Expand description
Audio data wrappers specific to the AudioUnit’s AudioFormat.
Required Methods
Sourcefn does_stream_format_match(stream_format: &StreamFormat) -> bool
fn does_stream_format_match(stream_format: &StreamFormat) -> bool
Check whether the stream format matches this type of data.
Sourceunsafe fn from_input_proc_args(
num_frames: u32,
io_data: *mut AudioBufferList,
) -> Self
unsafe fn from_input_proc_args( num_frames: u32, io_data: *mut AudioBufferList, ) -> Self
We must be able to construct Self from arguments given to the input_proc.
Safety
TODO document how to use this function safely.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".