SampleFormat

Enum SampleFormat 

pub enum SampleFormat {
    F32,
    I32,
    I24,
    I16,
    I8,
}
Dynamic representation of audio data sample format.

Variants



F32

32-bit float.



I32

32-bit signed integer.



I24

24-bit signed integer. Can be packed or not depending on the flags.



I16

16-bit signed integer.



I8

8-bit signed integer.

Implementations

Source

impl SampleFormat

pub fn does_match_flags(&self, flags: LinearPcmFlags) -> bool

Check if the format flags are appropriate for the given format.

pub fn from_flags_and_bits_per_sample( flags: LinearPcmFlags, bits_per_sample: u32, ) -> Option<Self>

Convert format flags and bits_per_sample to a SampleFormat.

pub fn size_in_bytes(&self) -> usize

Return the size of one sample in bytes, assuming that the format is packed.

pub fn size_in_bits(&self) -> u32

Return the number of valid bits for one sample.