Re-exports
pub use self::action_flags::ActionFlags;pub use self::data::Data;
Modules
- action_
flags - data
- Format specific render callback data.
Structs
- Args
- Arguments given to the render callback function.
- Input
Proc FnWrapper - This type allows us to safely wrap a boxed
RenderCallbackto use within the input proc.
Type Aliases
- Input
Proc Fn - When
set_render_callbackis called, a closure of this type will be used to wrap the given render callback function.